==> gnash-0.8.6.tar.gz: gnash-0.8.6/libcore/asobj/flash/events/TimerEvent_as.cpp <==
// TimerEvent_as.cpp:  ActionScript "TimerEvent" class, for Gnash.
//
//   Copyright (C) 2009 Free Software Foundation, Inc.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//

#ifdef HAVE_CONFIG_H
#include "gnashconfig.h"
#endif

#include "events/TimerEvent_as.h"
#include "log.h"
#include "fn_call.h"
#include "Global_as.h"
#include "smart_ptr.h" // for boost intrusive_ptr
#include "builtin_function.h" // need builtin_function
#include "GnashException.h" // for ActionException

namespace gnash {

// Forward declarations
namespace {
    as_value timerevent_toString(const fn_call& fn);
    as_value timerevent_updateAfterEvent(const fn_call& fn);
    as_value timerevent_TIMER(const fn_call& fn);
    as_value timerevent_TIMER_COMPLETE(const fn_call& fn);
    as_value timerevent_ctor(const fn_call& fn);
    void attachTimerEventInterface(as_object& o);
    void attachTimerEventStaticInterface(as_object& o);
}

// extern (used by Global.cpp)
void
timerevent_class_init(as_object& where, const ObjectURI& uri)
{
    registerBuiltinClass(where, timerevent_ctor, attachTimerEventInterface,
            attachTimerEventStaticInterface, uri);
}

namespace {

void
attachTimerEventInterface(as_object& o)
{
    Global_as* gl = getGlobal(o);
    o.init_member("toString", gl->createFunction(timerevent_toString));
    o.init_member("updateAfterEvent", gl->createFunction(timerevent_updateAfterEvent));
    o.init_member("TIMER", gl->createFunction(timerevent_TIMER));
    o.init_member("TIMER_COMPLETE", gl->createFunction(timerevent_TIMER_COMPLETE));
}

void
attachTimerEventStaticInterface(as_object& /*o*/)
{
}

as_value
timerevent_toString(const fn_call& /*fn*/)
{
    log_unimpl (__FUNCTION__);
    return as_value();
}

as_value
timerevent_updateAfterEvent(const fn_call& /*fn*/)
{
    log_unimpl (__FUNCTION__);
    return as_value();
}

as_value
timerevent_TIMER(const fn_call& /*fn*/)
{
    log_unimpl (__FUNCTION__);
    return as_value();
}

as_value
timerevent_TIMER_COMPLETE(const fn_call& /*fn*/)
{
    log_unimpl (__FUNCTION__);
    return as_value();
}

as_value
timerevent_ctor(const fn_call& /*fn*/)
{

    return as_value(); // will keep alive
}

} // anonymous namespace 
} // gnash namespace

// local Variables:
// mode: C++
// indent-tabs-mode: t
// End:

==> gnash_0.8.7.orig.tar.gz: gnash-0.8.7/libcore/asobj/flash/events/TimerEvent_as.cpp <==
// TimerEvent_as.cpp:  ActionScript "TimerEvent" class, for Gnash.
//
//   Copyright (C) 2009, 2010 Free Software Foundation, Inc.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//


#include "events/TimerEvent_as.h"
#include "log.h"
#include "fn_call.h"
#include "Global_as.h"
#include "smart_ptr.h" // for boost intrusive_ptr
#include "builtin_function.h" // need builtin_function
#include "GnashException.h" // for ActionException

namespace gnash {

// Forward declarations
namespace {
    as_value timerevent_toString(const fn_call& fn);
    as_value timerevent_updateAfterEvent(const fn_call& fn);
    as_value timerevent_TIMER(const fn_call& fn);
    as_value timerevent_TIMER_COMPLETE(const fn_call& fn);
    as_value timerevent_ctor(const fn_call& fn);
    void attachTimerEventInterface(as_object& o);
    void attachTimerEventStaticInterface(as_object& o);
}

// extern (used by Global.cpp)
void
timerevent_class_init(as_object& where, const ObjectURI& uri)
{
    registerBuiltinClass(where, timerevent_ctor, attachTimerEventInterface,
            attachTimerEventStaticInterface, uri);
}

namespace {

void
attachTimerEventInterface(as_object& o)
{
    Global_as& gl = getGlobal(o);
    o.init_member("toString", gl.createFunction(timerevent_toString));
    o.init_member("updateAfterEvent", gl.createFunction(timerevent_updateAfterEvent));
    o.init_member("TIMER", gl.createFunction(timerevent_TIMER));
    o.init_member("TIMER_COMPLETE", gl.createFunction(timerevent_TIMER_COMPLETE));
}

void
attachTimerEventStaticInterface(as_object& /*o*/)
{
}

as_value
timerevent_toString(const fn_call& /*fn*/)
{
    log_unimpl (__FUNCTION__);
    return as_value();
}

as_value
timerevent_updateAfterEvent(const fn_call& /*fn*/)
{
    log_unimpl (__FUNCTION__);
    return as_value();
}

as_value
timerevent_TIMER(const fn_call& /*fn*/)
{
    log_unimpl (__FUNCTION__);
    return as_value();
}

as_value
timerevent_TIMER_COMPLETE(const fn_call& /*fn*/)
{
    log_unimpl (__FUNCTION__);
    return as_value();
}

as_value
timerevent_ctor(const fn_call& /*fn*/)
{

    return as_value(); // will keep alive
}

} // anonymous namespace 
} // gnash namespace

// local Variables:
// mode: C++
// indent-tabs-mode: t
// End:
